@@ -4,7 +4,7 @@ use Mojo::Base -base;
 use Role::Tiny;
 use Carp qw/croak/;
 
-our $VERSION = '1.001008'; # VERSION
+our $VERSION = '1.002001'; # VERSION
 
 sub click_ok {
     my ( $self, $selector, $extra_params ) = @_;
@@ -45,7 +45,7 @@ sub click_ok {
     }
 
     my $tx = $self->ua->build_tx(
-        $el->{method}||'GET' => $el->{action}
+        $el->{method}||'GET' => defined $el->{action} && $el->{action} ne '' ? $el->{action} : $self->tx->req->url
             => form => \%form,
     );
 
@@ -228,10 +228,18 @@ to C<bug-test-mojo-role-SubmitForm at rt.cpan.org>
 
 =for html  </div></div>
 
+=head1 CONTRIBUTORS
+
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-contributors.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+
+=for html   <span style="display: inline-block; text-align: center;"> <a href="http://metacpan.org/author/PLICEASE"> <img src="http://www.gravatar.com/avatar/0640fb1c0a5e82f5a777f2306efcac77?d=http%3A%2F%2Fwww.gravatar.com%2Favatar%2F0640fb1c0a5e82f5a777f2306efcac77" alt="PLICEASE" style="display: block; margin: 0 3px 5px 0!important; border: 1px solid #666; border-radius: 3px; "> <span style="color: #333; font-weight: bold;">PLICEASE</span> </a> </span>
+
+=for html  </div></div>
+
 =head1 LICENSE
 
 You can use and distribute this module under the same terms as Perl itself.
 See the C<LICENSE> file included in this distribution for complete
 details.
 
-=cut
\ No newline at end of file
+=cut
